@@ -20,12 +20,10 @@ setupClusters <- function(num.cores = 1, max.cores = NULL) {
   if(max.cores < 1) max.cores <- 1
   num.cores <- min(num.cores, max.cores)
   if(num.cores > 1) {
-    parallel::makePSOCKcluster(num.cores)
-    # cl.func <- ifelse(
-    #   .Platform$OS.type == "windows", 
-    #   parallel::makePSOCKcluster, 
-    #   parallel::makeForkCluster
-    # )
-    # cl.func(num.cores)
+    if(.Platform$OS.type == "windows") {
+      parallel::makePSOCKcluster(num.cores)
+    } else {
+      parallel::makeForkCluster(num.cores)
+    }
   } else NULL
 }
\ No newline at end of file
